KdlCountry2 class
ISO 3166-1 alpha-2 country code.
- Inheritance
-
- Object
- KdlValue<
Country> - KdlCountry
- KdlCountry2
Constructors
- KdlCountry2(Country value, [String? type])
-
Construct a new
KdlCountry2
Properties
Methods
-
asType(
String type, [KdlTypeParser< KdlValue> ? parser]) → KdlValue -
Sets the type of a value. If a
parseris provided, calls the function with the value and type and returns the result if any, otherwise returnsthisinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convert(
KdlValue value, [String type = 'country2']) → KdlCountry2? -
Convert a
KdlStringintoKdlCountry2