KdlDecimal class
IEEE 754-2008 decimal string format.
Constructors
- KdlDecimal(BigDecimal value, [String? type])
-
Construct a new
KdlDecimal
Properties
Methods
-
asType(
String type, [KdlTypeParser< KdlValue> ? parser]) → KdlValue -
Sets the type of a value. If a
parseris provided, calls the function with the value and type and returns the result if any, otherwise returnsthisinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convert(
KdlValue value, [String type = 'decimal']) → KdlDecimal? -
Convert a
KdlStringinto aKdlDecimal