KdlDouble class

KDL Value wrapping a double

Inheritance

Constructors

KdlDouble(double value, [String? type])
Construct a new KDL Double

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Optional type annotation
getter/setter pairinherited
value double
Internally stored value
getter/setter pairinherited

Methods

asType(String type, [KdlTypeParser<KdlValue>? parser]) KdlValue
Sets the type of a value. If a parser is provided, calls the function with the value and type and returns the result if any, otherwise returns this
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override