KdlEmail class
RFC5322 email address.
- Inheritance
- Implementers
Constructors
Properties
- domain ↔ String
-
Domain email address part
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- local ↔ String
-
Local email address part
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
Optional type annotation
getter/setter pairinherited
- value ↔ String
-
Internally stored value
getter/setter pairinherited
Methods
-
asType(
String type, [KdlTypeParser< KdlValue> ? parser]) → KdlValue -
Sets the type of a value. If a
parseris provided, calls the function with the value and type and returns the result if any, otherwise returnsthisinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited