KdlHostname class
RFC1132 internet hostname (only ASCII segments)
- Inheritance
- Implementers
Constructors
- KdlHostname(String value, [String? type])
-
Construct a new
KdlHostname
Properties
Methods
-
asType(
String type, [KdlTypeParser< KdlValue> ? parser]) → KdlValue -
Sets the type of a value. If a
parseris provided, calls the function with the value and type and returns the result if any, otherwise returnsthisinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convert(
KdlValue value, [String type = 'hostname']) → KdlHostname? -
Convert a
KdlStringinto aKdlHostname