KdlIdnEmail class

RFC6531 internationalized email address.

Inheritance

Constructors

KdlIdnEmail(String value, String unicodeValue, String local, String domain, String unicodeDomain, [String? type])
Construct a new KdlIDNEmail

Properties

domain String
Domain email address part
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
local String
Local email address part
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Optional type annotation
getter/setter pairinherited
unicodeDomain String
Unicode IDN
getter/setter pair
unicodeValue String
Unicode value
getter/setter pair
value String
Internally stored value
getter/setter pairinherited

Methods

asType(String type, [KdlTypeParser<KdlValue>? parser]) KdlValue
Sets the type of a value. If a parser is provided, calls the function with the value and type and returns the result if any, otherwise returns this
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

convert(KdlValue value, [String type = 'idn-email']) KdlIdnEmail?
Convert a KdlString into a KdlIDNEmail
override