KdlNull class

KDL Value representing null

Inheritance

Constructors

KdlNull()
Return the untyped singleton KDL Null
factory
KdlNull.withType(String type)
Construct a new KDL Null with a type annotation

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Optional type annotation
getter/setter pairinherited
value Null
Internally stored value
getter/setter pairinherited

Methods

asType(String type, [KdlTypeParser<KdlValue>? parser]) KdlValue
Returns a new KDL Null with the given type. If a parser is passed in, calls it with the current value and returns the result if any, otherwise falls back to creating a new Null with the given type annotation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override