KdlParseException class

Exception thrown when attempting to parse an invalid KDL document

Inheritance

Constructors

KdlParseException(String message, [int? line, int? column])
Construct a new KDL Parse Exception with the given message, and optionally the line and column numbers where the error happened

Properties

column int?
The column where the parse error happened
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
line int?
The line number where the parse error happened
getter/setter pair
message String
Exception message
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited