KdlParseException constructor

KdlParseException(
  1. String message, [
  2. int? line,
  3. int? column
])

Construct a new KDL Parse Exception with the given message, and optionally the line and column numbers where the error happened

Implementation

KdlParseException(super.message, [this.line, this.column]);