KdlUrlTemplate class

RFC6570 URI Template.

Inheritance

Constructors

KdlUrlTemplate(UrlTemplate value, [String? type])
Construct a new KdlURLTemplate

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Optional type annotation
getter/setter pairinherited
value ↔ UrlTemplate
Internally stored value
getter/setter pairinherited

Methods

asType(String type, [KdlTypeParser<KdlValue>? parser]) KdlValue
Sets the type of a value. If a parser is provided, calls the function with the value and type and returns the result if any, otherwise returns this
inherited
expand(dynamic values) Uri
Expand the template into a Uri using the given values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

convert(KdlValue value, [String type = 'url-emplate']) KdlUrlTemplate?
Convert a KdlString into a KdlURLTemplate