KdlValue<T> class abstract

Base class for all KDL Value types

Implementers

Constructors

KdlValue(T value, [String? type])
Construct a new KDL Value with a given internal value and optional type

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Optional type annotation
getter/setter pair
value ↔ T
Internally stored value
getter/setter pair

Methods

asType(String type, [KdlTypeParser<KdlValue>? parser]) KdlValue
Sets the type of a value. If a parser is provided, calls the function with the value and type and returns the result if any, otherwise returns this
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

from(dynamic v, [String? type]) KdlValue
Create the appropriate KDL Value from the given native value