KdlVersionMismatchException class

Exception thrown when attempting to parse a versioned KDL document with the incorrect parser version

Inheritance

Constructors

KdlVersionMismatchException(int version, int parserVersion)
Construct a new KDL Version Mismatch Exception for the given document and parser versions

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Exception message
getter/setter pairinherited
parserVersion int
The version of the parser
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
The version of the document
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited