KdlCountrySubdivision class
ISO 3166-2 country subdivision code.
Constructors
- KdlCountrySubdivision(String value, String name, Country country, [String? type])
- Construct a new KDL Country Subdivision
Properties
- country ↔ Country
-
The country in which the subdivision resides
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
Name of the subdivision
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
Optional type annotation
getter/setter pairinherited
- value ↔ String
-
Internally stored value
getter/setter pairinherited
Methods
-
asType(
String type, [KdlTypeParser< KdlValue> ? parser]) → KdlValue -
Sets the type of a value. If a
parseris provided, calls the function with the value and type and returns the result if any, otherwise returnsthisinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convert(
KdlValue value, [String type = 'country-subdivision']) → KdlCountrySubdivision? -
Convert a
KdlStringinto aKdlCountrySubdivision