KdlIRL class
RFC3987 Internationalized Resource Identifier.
- Inheritance
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
Optional type annotation
getter/setter pairinherited
- unicodeDomain ↔ String?
-
Unicode domain
getter/setter pair
- unicodeHash ↔ String?
-
Unicode hash value
getter/setter pair
- unicodePath ↔ String?
-
Unicode path
getter/setter pair
- unicodeSearch ↔ String?
-
Unicode search query
getter/setter pair
- unicodeValue ↔ String
-
Unicode value
getter/setter pair
- value ↔ Uri
-
Internally stored value
getter/setter pairinherited
Methods
-
asType(
String type, [KdlTypeParser< KdlValue> ? parser]) → KdlValue -
Sets the type of a value. If a
parseris provided, calls the function with the value and type and returns the result if any, otherwise returnsthisinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited