KdlIdnHostname class
RFC5890 internationalized internet hostname
(only xn---prefixed ASCII "punycode" segments, or non-ASCII segments)
- Inheritance
-
- Object
- KdlValue<
String> - KdlHostname
- KdlIdnHostname
Constructors
- KdlIdnHostname(String value, String unicodeValue, [String? type])
-
Construct a new
KdlIDNHostname
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
Optional type annotation
getter/setter pairinherited
- unicodeValue ↔ String
-
Unicode value
getter/setter pair
- value ↔ String
-
Internally stored value
getter/setter pairinherited
Methods
-
asType(
String type, [KdlTypeParser< KdlValue> ? parser]) → KdlValue -
Sets the type of a value. If a
parseris provided, calls the function with the value and type and returns the result if any, otherwise returnsthisinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convert(
KdlValue value, [String type = 'idn-hostname']) → KdlIdnHostname? -
Convert a
KdlStringinto aKdlIDNHostnameoverride