KdlIrlReference class
RFC3987 Internationalized Resource Identifier Reference.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
Optional type annotation
getter/setter pairinherited
- unicodeDomain ↔ String?
-
Unicode domain
getter/setter pairinherited
- unicodeHash ↔ String?
-
Unicode hash value
getter/setter pairinherited
- unicodePath ↔ String?
-
Unicode path
getter/setter pairinherited
- unicodeSearch ↔ String?
-
Unicode search query
getter/setter pairinherited
- unicodeValue ↔ String
-
Unicode value
getter/setter pairinherited
- value ↔ Uri
-
Internally stored value
getter/setter pairinherited
Methods
-
asType(
String type, [KdlTypeParser< KdlValue> ? parser]) → KdlValue -
Sets the type of a value. If a
parseris provided, calls the function with the value and type and returns the result if any, otherwise returnsthisinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convert(
KdlValue value, [String type = 'irl-reference']) → KdlIrlReference? -
Converts a
KdlStringinto aKdlIRLReferenceoverride