KdlUrlTemplate class
RFC6570 URI Template.
Constructors
- KdlUrlTemplate(UrlTemplate value, [String? type])
-
Construct a new
KdlURLTemplate
Properties
Methods
-
asType(
String type, [KdlTypeParser< KdlValue> ? parser]) → KdlValue -
Sets the type of a value. If a
parseris provided, calls the function with the value and type and returns the result if any, otherwise returnsthisinherited -
expand(
dynamic values) → Uri - Expand the template into a Uri using the given values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convert(
KdlValue value, [String type = 'url-emplate']) → KdlUrlTemplate? -
Convert a
KdlStringinto aKdlURLTemplate